==> versatile-kernel-2.6.18.1-compiled.tar.bz2: linux-2.6.18.1/drivers/md/dm-crypt.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0xe3e52f33, "struct_module" },
	{ 0xb3d17436, "dm_unregister_target" },
	{ 0xb9f66ce8, "kmem_cache_destroy" },
	{ 0x7e65dca8, "destroy_workqueue" },
	{ 0xc102cbea, "dm_register_target" },
	{ 0x47ea848c, "__create_workqueue" },
	{ 0x86ea1981, "kmem_cache_create" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x28f35813, "scnprintf" },
	{ 0x1d17e4bd, "blk_congestion_wait" },
	{ 0xe3e31325, "generic_make_request" },
	{ 0x9d669763, "memcpy" },
	{ 0x1ef0986e, "bio_alloc" },
	{ 0x7e4644ad, "bio_clone" },
	{ 0xab53b0a8, "mempool_alloc" },
	{ 0x14ed9194, "queue_work" },
	{ 0x35fe47a1, "init_timer" },
	{ 0xbc1fe960, "dm_put_device" },
	{ 0xd985dc99, "mempool_free_pages" },
	{ 0x53326531, "mempool_alloc_pages" },
	{ 0x8a99a016, "mempool_free_slab" },
	{ 0x183fa88b, "mempool_alloc_slab" },
	{ 0xac54fc9f, "mempool_destroy" },
	{ 0xe914e41e, "strcpy" },
	{ 0x2e1c602d, "dm_get_device" },
	{ 0xc75ce50, "dm_table_get_mode" },
	{ 0x859204af, "sscanf" },
	{ 0x1f7cc628, "mempool_create" },
	{ 0x20000329, "simple_strtoul" },
	{ 0xe2d5255a, "strcmp" },
	{ 0x97255bdf, "strlen" },
	{ 0xdd132261, "printk" },
	{ 0x85df9b6c, "strsep" },
	{ 0xe284e7a5, "bio_endio" },
	{ 0xf548a949, "bio_put" },
	{ 0x62aba95, "mempool_free" },
	{ 0x5f754e5a, "memset" },
	{ 0xfb5e401, "mem_map" },
	{ 0x37a0cba, "kfree" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0x975449cf, "crypto_free_tfm" },
	{ 0x1551357c, "crypto_alloc_tfm" },
	{ 0xfa2a45e, "__memzero" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=dm-mod";

==> versatile-kernel-2.6.19.1-compiled.tar.bz2: linux-2.6.19.1/drivers/md/dm-crypt.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0x528a560b, "struct_module" },
	{ 0x54782e54, "dm_unregister_target" },
	{ 0xaadf600c, "kmem_cache_destroy" },
	{ 0xc350c214, "destroy_workqueue" },
	{ 0xa3f60d5d, "dm_register_target" },
	{ 0xda5242cf, "__create_workqueue" },
	{ 0x86ea1981, "kmem_cache_create" },
	{ 0x4e830a3e, "strnicmp" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x28f35813, "scnprintf" },
	{ 0x862de35d, "dm_put_device" },
	{ 0xd985dc99, "mempool_free_pages" },
	{ 0x53326531, "mempool_alloc_pages" },
	{ 0x8a99a016, "mempool_free_slab" },
	{ 0x183fa88b, "mempool_alloc_slab" },
	{ 0xac54fc9f, "mempool_destroy" },
	{ 0x661e6ec8, "bioset_free" },
	{ 0x2ea414c5, "dm_get_device" },
	{ 0xbef08ad2, "dm_table_get_mode" },
	{ 0x859204af, "sscanf" },
	{ 0x1c875572, "bioset_create" },
	{ 0x1f7cc628, "mempool_create" },
	{ 0xe914e41e, "strcpy" },
	{ 0x25da070, "snprintf" },
	{ 0x12f237eb, "__kzalloc" },
	{ 0xdd132261, "printk" },
	{ 0x85df9b6c, "strsep" },
	{ 0x20000329, "simple_strtoul" },
	{ 0xe2d5255a, "strcmp" },
	{ 0x97255bdf, "strlen" },
	{ 0x64999478, "congestion_wait" },
	{ 0xab53b0a8, "mempool_alloc" },
	{ 0x29a164ce, "__bio_clone" },
	{ 0xb4e36e2e, "generic_make_request" },
	{ 0x9d669763, "memcpy" },
	{ 0x886d4dad, "bio_alloc_bioset" },
	{ 0xc2e31ddd, "queue_work" },
	{ 0x35fe47a1, "init_timer" },
	{ 0x37fa3b81, "bio_endio" },
	{ 0xeb3d6aad, "bio_put" },
	{ 0x62aba95, "mempool_free" },
	{ 0x85ae6023, "bio_free" },
	{ 0x5f754e5a, "memset" },
	{ 0x2f9838ed, "mem_map" },
	{ 0x37a0cba, "kfree" },
	{ 0xca530a3, "crypto_free_tfm" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0x1fb30b1f, "crypto_alloc_base" },
	{ 0xfa2a45e, "__memzero" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=dm-mod";
